==> nextcloud-app-spreed-1:15.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/l10n/et_EE.js <==
OC.L10N.register(
    "spreed",
    {
    "_%n guest_::_%n guests_" : ["%n külaline","%n külalist"],
    "Talk" : "Talk",
    "Guest" : "Külaline",
    "File is too big" : "Fail on liiga suur",
    "Invalid file provided" : "Vigane fail",
    "Invalid image" : "Vigane pilt",
    "Unknown filetype" : "Tundmatu failitüüp",
    "An error occurred. Please contact your admin." : "Tekkis tõrge. Palun võta ühendust administraatoriga.",
    "Invalid date, date format must be YYYY-MM-DD" : "Vigane kuupäev, formaat peab olema YYYY-MM-DD",
    "Limit to groups" : "Luba gruppidele",
    "Everyone" : "Igaüks",
    "Save changes" : "Salvesta muudatused",
    "Saved!" : "Salvestatud!",
    "None" : "Pole",
    "User" : "Kasutaja",
    "Disabled" : "Keelatud",
    "Users" : "Kasutajad",
    "Name" : "Nimi",
    "Language" : "Keel",
    "Country" : "Riik",
    "Status" : "Staatus",
    "Created at" : "Loodud",
    "Pending" : "Ootel",
    "Error" : "Viga",
    "Blocked" : "Blokeeritud",
    "Expired" : "Aegunud",
    "Delete this server" : "Kustuta see server",
    "OK" : "OK",
    "Copy link" : "Kopeeri link",
    "Dismiss" : "Jäta vahele",
    "Grid view" : "Ruudustikvaade",
    "Screensharing requires the page to be loaded through HTTPS." : "Ekraanijagamiseks tuleb leht laadida üle HTTPS protokolli.",
    "Back" : "Tagasi",
    "You" : "Sina",
    "Favorite" : "Lemmik",
    "Restricted" : "Piiratud",
    "Description" : "Kirjeldus",
    "Notifications" : "Teavitused",
    "Password protection" : "Password protection",
    "Enter a password" : "Enter a password",
    "Save" : "Salvesta",
    "Edit" : "Redigeeri",
    "Delete" : "Kustuta",
    "Password" : "Parool",
    "API token" : "API kood",
    "Login" : "Logi sisse",
    "Nickname" : "Hüüdnimi",
    "Client ID" : "Kliendi ID",
    "Remove from favorites" : "Eemalda lemmikutest",
    "Add to favorites" : "Lisa lemmikutesse",
    "Loading" : "Laadimine",
    "Groups" : "Grupid",
    "Password protect" : "Parooliga kaitsmine",
    "Close" : "Sulge",
    "Reply" : "Vasta",
    "Contact" : "Kontakt",
    "Today" : "Täna",
    "Yesterday" : "Eile",
    "Create new poll" : "Loo uus küsitlus",
    "New file" : "Uus fail",
    "Settings" : "Seaded",
    "Create poll" : "Loo küsitlus",
    "guest" : "külaline",
    "Searching …" : "Otsin ...",
    "No results" : "Vasteid ei leitud",
    "Add users or groups" : "Add users or groups",
    "Details" : "Üksikasjad",
    "Privacy" : "Privaatsus",
    "Keyboard shortcuts" : "Klaviatuuri otseteed",
    "Search" : "Otsi",
    "Send" : "Saada",
    "Files" : "Failid",
    "Polls" : "Küsitlused",
    "Locations" : "Asukohad",
    "Audio" : "Helid",
    "Other" : "Muu",
    "Default" : "Vaikeväärtus",
    "The password is wrong. Try again." : "Parool on vale. Proovi uuesti.",
    "Android app" : "Androidi rakendus",
    "iOS app" : "iOS-i rakendus",
    "Saved" : "Salvestatud"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-spreed-1:17.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/l10n/et_EE.js <==
OC.L10N.register(
    "spreed",
    {
    "_%n guest_::_%n guests_" : ["%n külaline","%n külalist"],
    "Talk" : "Talk",
    "Guest" : "Külaline",
    "File is too big" : "Fail on liiga suur",
    "Invalid file provided" : "Vigane fail",
    "Invalid image" : "Vigane pilt",
    "Unknown filetype" : "Tundmatu failitüüp",
    "Avatar image is not square" : "Avatari pilt pole ruut",
    "Invalid date, date format must be YYYY-MM-DD" : "Vigane kuupäev, formaat peab olema YYYY-MM-DD",
    "Limit to groups" : "Luba gruppidele",
    "Everyone" : "Igaüks",
    "Save changes" : "Salvesta muudatused",
    "Saving …" : "Salvestamine …",
    "Saved!" : "Salvestatud!",
    "Name" : "Nimi",
    "None" : "Pole",
    "User" : "Kasutaja",
    "Disabled" : "Keelatud",
    "Users" : "Kasutajad",
    "Language" : "Keel",
    "Country" : "Riik",
    "Status" : "Staatus",
    "Created at" : "Loodud",
    "Pending" : "Ootel",
    "Error" : "Viga",
    "Blocked" : "Blokeeritud",
    "Expired" : "Aegunud",
    "Delete this server" : "Kustuta see server",
    "OK" : "OK",
    "Back" : "Tagasi",
    "Confirm" : "Kinnita",
    "Reset" : "Lähtesta",
    "Cancel" : "Loobu",
    "Copy link" : "Kopeeri link",
    "You" : "Sina",
    "Collapse" : "Sulge",
    "Favorite" : "Lemmik",
    "Description" : "Kirjeldus",
    "Restricted" : "Piiratud",
    "Personal" : "Isiklik",
    "Submit" : "Saada",
    "Password protection" : "Password protection",
    "Save" : "Salvesta",
    "Edit" : "Redigeeri",
    "Delete" : "Kustuta",
    "Password" : "Parool",
    "API token" : "API kood",
    "Login" : "Logi sisse",
    "Nickname" : "Hüüdnimi",
    "Client ID" : "Kliendi ID",
    "Notifications" : "Teavitused",
    "Remove from favorites" : "Eemalda lemmikutest",
    "Add to favorites" : "Lisa lemmikutesse",
    "Loading" : "Laadimine",
    "Groups" : "Grupid",
    "Password protect" : "Parooliga kaitsmine",
    "Close" : "Sulge",
    "Devices" : "Seadmed",
    "Done" : "Valmis",
    "Upload" : "Lae üles",
    "Files" : "Failid",
    "Dismiss" : "Jäta vahele",
    "Reply" : "Vasta",
    "Translate" : "Tõlgi",
    "Copy translated text" : "Kopeeri tõlgitud tekst",
    "Contact" : "Kontakt",
    "Today" : "Täna",
    "Yesterday" : "Eile",
    "Group" : "Grupp",
    "Create new poll" : "Loo uus küsitlus",
    "New file" : "Uus fail",
    "Blank" : "Tühi",
    "Settings" : "Seaded",
    "Create poll" : "Loo küsitlus",
    "Send" : "Saada",
    "guest" : "külaline",
    "Searching …" : "Otsin ...",
    "No results" : "Vasteid ei leitud",
    "Add users or groups" : "Add users or groups",
    "Details" : "Üksikasjad",
    "Privacy" : "Privaatsus",
    "Keyboard shortcuts" : "Klaviatuuri otseteed",
    "Search" : "Otsi",
    "Open sidebar" : "Ava külgriba",
    "Screensharing requires the page to be loaded through HTTPS." : "Ekraanijagamiseks tuleb leht laadida üle HTTPS protokolli.",
    "Grid view" : "Ruudustikvaade",
    "Media" : "Meedia",
    "Polls" : "Küsitlused",
    "Locations" : "Asukohad",
    "Audio" : "Helid",
    "Other" : "Muu",
    "Do not disturb" : "Mitte segada",
    "Away" : "Eemal",
    "Default" : "Vaikeväärtus",
    "The password is wrong. Try again." : "Parool on vale. Proovi uuesti.",
    "Android app" : "Androidi rakendus",
    "iOS app" : "iOS-i rakendus"
},
"nplurals=2; plural=(n != 1);");
